==> cosxml-5.4.24-sources.jar: com/tencent/cos/xml/common/COSRequestHeaderKey.java <==
package com.tencent.cos.xml.common;

/**
 * Created by bradyxiao on 2017/11/30.
 */

final public class COSRequestHeaderKey {
    public final static String X_COS_ACL = "x-cos-acl";
    public final static String X_COS_GRANT_READ = "x-cos-grant-read";
    public final static String X_COS_GRANT_WRITE = "x-cos-grant-write";
    public final static String X_COS_GRANT_FULL_CONTROL = "x-cos-grant-full-control";
    public final static String CACHE_CONTROL = "Cache-Control";
    public final static String CONTENT_DISPOSITION = "Content-Disposition";
    public final static String CONTENT_ENCODING = "Content-Encoding";
    public final static String EXPIRES = "Expires";
    public final static String X_COS_COPY_SOURCE = "x-cos-copy-source";
    public final static String X_COS_METADATA_DIRECTIVE = "x-cos-metadata-directive";
    public final static String X_COS_COPY_SOURCE_IF_MODIFIED_SINCE= "x-cos-copy-source-If-Modified-Since";
    public final static String X_COS_COPY_SOURCE_IF_UNMODIFIED_SINCE = "x-cos-copy-source-If-Unmodified-Since";
    public final static String X_COS_COPY_SOURCE_IF_MATCH = "x-cos-copy-source-If-Match";
    public final static String X_COS_COPY_SOURCE_IF_NONE_MATCH = "x-cos-copy-source-If-None-Match";
    public final static String X_COS_STORAGE_CLASS_ = "x-cos-storage-class";
    public final static String X_COS_COPY_SOURCE_RANGE = "x-cos-copy-source-range";
    public final static String ORIGIN = "Origin";
    public final static String ACCESS_CONTROL_REQUEST_METHOD = "Access-Control-Request-Method";
    public final static String ACCESS_CONTROL_REQUEST_HEADERS = "Access-Control-Request-Headers";
    public final static String IF_MODIFIED_SINCE = "If-Modified-Since";
    public final static String IF_UNMODIFIED_SINCE = "If-Unmodified-Since";
    public final static String IF_MATCH = "If-Match";
    public final static String IF_NONE_MATCH = "If-None-Match";
    public final static String APPLICATION_XML = "application/xml";
    public final static String TEXT_PLAIN = "text/plain";
    public final static String APPLICATION_OCTET_STREAM = "application/octet-stream";
    public final static String RANGE = "Range";
}

==> cosxml-5.5.3-sources.jar: com/tencent/cos/xml/common/COSRequestHeaderKey.java <==
package com.tencent.cos.xml.common;

/**
 * Created by bradyxiao on 2017/11/30.
 */

final public class COSRequestHeaderKey {
    public final static String X_COS_ACL = "x-cos-acl";
    public final static String X_COS_GRANT_READ = "x-cos-grant-read";
    public final static String X_COS_GRANT_WRITE = "x-cos-grant-write";
    public final static String X_COS_GRANT_READ_ACP = "x-cos-grant-read-acp";
    public final static String X_COS_GRANT_WRITE_ACP = "x-cos-grant-write-acp";
    public final static String X_COS_GRANT_FULL_CONTROL = "x-cos-grant-full-control";
    public final static String CACHE_CONTROL = "Cache-Control";
    public final static String CONTENT_DISPOSITION = "Content-Disposition";
    public final static String CONTENT_ENCODING = "Content-Encoding";
    public final static String EXPIRES = "Expires";
    public final static String X_COS_COPY_SOURCE = "x-cos-copy-source";
    public final static String X_COS_METADATA_DIRECTIVE = "x-cos-metadata-directive";
    public final static String X_COS_COPY_SOURCE_IF_MODIFIED_SINCE= "x-cos-copy-source-If-Modified-Since";
    public final static String X_COS_COPY_SOURCE_IF_UNMODIFIED_SINCE = "x-cos-copy-source-If-Unmodified-Since";
    public final static String X_COS_COPY_SOURCE_IF_MATCH = "x-cos-copy-source-If-Match";
    public final static String X_COS_COPY_SOURCE_IF_NONE_MATCH = "x-cos-copy-source-If-None-Match";
    public final static String X_COS_STORAGE_CLASS_ = "x-cos-storage-class";
    public final static String X_COS_COPY_SOURCE_RANGE = "x-cos-copy-source-range";
    public final static String ORIGIN = "Origin";
    public final static String ACCESS_CONTROL_REQUEST_METHOD = "Access-Control-Request-Method";
    public final static String ACCESS_CONTROL_REQUEST_HEADERS = "Access-Control-Request-Headers";
    public final static String IF_MODIFIED_SINCE = "If-Modified-Since";
    public final static String IF_UNMODIFIED_SINCE = "If-Unmodified-Since";
    public final static String IF_MATCH = "If-Match";
    public final static String IF_NONE_MATCH = "If-None-Match";
    public final static String APPLICATION_XML = "application/xml";
    public final static String TEXT_PLAIN = "text/plain";
    public final static String APPLICATION_OCTET_STREAM = "application/octet-stream";
    public final static String RANGE = "Range";
}
